@@ -22,57 +22,38 @@ from datetime import timedelta
 from pprint import PrettyPrinter
 from typing import Any, Dict, List, Union
 
-from aioswitcher.api import Command, SwitcherType1Api, SwitcherType2Api
+from aioswitcher.api import Command, SwitcherApi
 from aioswitcher.api.remotes import SwitcherBreezeRemoteManager
 from aioswitcher.device import (
     DeviceState,
     DeviceType,
+    ShutterChildLock,
     ThermostatFanLevel,
     ThermostatMode,
     ThermostatSwing,
 )
-from aioswitcher.device.tools import convert_str_to_devicetype
 from aioswitcher.schedule import Days
 
 printer = PrettyPrinter(indent=4)
 
-_examples = """example usage:
-
-python control_device.py get_state -c "Switcher Touch" -d ab1c2d -i "111.222.11.22"\n
-python control_device.py turn_on -c "Switcher Touch" -d ab1c2d -i "111.222.11.22"\n
-python control_device.py turn_on -c "Switcher Touch" -d ab1c2d -l 18 -i "111.222.11.22"\n
-python control_device.py turn_on -c "Switcher Touch" -d ab1c2d -i "111.222.11.22" -t 15\n
-python control_device.py turn_off -c "Switcher Touch" -d ab1c2d -i "111.222.11.22"\n
-python control_device.py turn_off -c "Switcher Touch" -d ab1c2d -l 18 -i "111.222.11.22"\n
-python control_device.py set_name -c "Switcher Touch" -d ab1c2d -i "111.222.11.22" -n "My Boiler"\n
-python control_device.py set_auto_shutdown -c "Switcher Touch" -d ab1c2d -i "111.222.11.22" -r 2 -m 30\n
-python control_device.py get_schedules -c "Switcher Touch" -d ab1c2d -i "111.222.11.22"\n
-python control_device.py delete_schedule -c "Switcher Touch" -d ab1c2d -i "111.222.11.22" -s 3\n
-python control_device.py create_schedule -c "Switcher Touch" -d ab1c2d -i "111.222.11.22" -n "14:00" -f "14:30"\n
-python control_device.py create_schedule -c "Switcher Touch" -d ab1c2d -i "111.222.11.22" -n "17:30" -f "18:30" -w Sunday Monday Friday\n
-
-python control_device.py get_shutter_state -c "Switcher Runner" -d f2239a -i "192.168.50.98"\n
-python control_device.py get_shutter_state -c "Switcher Runner S11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98"\n
-python control_device.py stop_shutter -c "Switcher Runner" -d f2239a -i "192.168.50.98"\n
-python control_device.py stop_shutter -c "Switcher Runner S11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98"\n
-python control_device.py set_shutter_position -c "Switcher Runner" -d f2239a -i "192.168.50.98" -p 50\n
-python control_device.py set_shutter_position -c "Switcher Runner S11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98" -p 50\n
-
-python control_device.py get_light_state -c "Switcher Runner S11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
-python control_device.py get_light_state -c "Switcher Runner S11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
-python control_device.py turn_on_light -c "Switcher Runner S11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
-python control_device.py turn_on_light -c "Switcher Runner S11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
-python control_device.py turn_off_light -c "Switcher Runner S11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
-python control_device.py turn_off_light -c "Switcher Runner S11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
-
-python control_device.py get_thermostat_state -c "Switcher Breeze" -d 3a20b7 -i "192.168.50.77"\n
-
-python control_device.py control_thermostat -c "Switcher Breeze" -d 3a20b7 -i "192.168.50.77" -r ELEC7001 -s on\n
-python control_device.py control_thermostat -c "Switcher Breeze" -d 3a20b7 -i "192.168.50.77" -r ELEC7001 -m cool -f high -t 24\n
-python control_device.py control_thermostat -c "Switcher Breeze" -d 3a20b7 -i "192.168.50.77" -r ELEC7001 -m cool -f high -t 24 -u\n
-python control_device.py control_thermostat -c "Switcher Breeze" -d 3a20b7 -i "192.168.50.77" -r ELEC7001 -m dry\n
-python control_device.py control_thermostat -c "Switcher Breeze" -d 3a20b7 -i "192.168.50.77" -r ELEC7001 -s off\n
-"""  # noqa E501
+DEVICES = {
+    "mini": DeviceType.MINI,
+    "plug": DeviceType.POWER_PLUG,
+    "touch": DeviceType.TOUCH,
+    "v2esp": DeviceType.V2_ESP,
+    "v2qual": DeviceType.V2_QCA,
+    "v4": DeviceType.V4,
+    "breeze": DeviceType.BREEZE,
+    "runner": DeviceType.RUNNER,
+    "runnermini": DeviceType.RUNNER_MINI,
+    "runners11": DeviceType.RUNNER_S11,
+    "runners12": DeviceType.RUNNER_S12,
+    "light01": DeviceType.LIGHT_SL01,
+    "light01mini": DeviceType.LIGHT_SL01_MINI,
+    "light02": DeviceType.LIGHT_SL02,
+    "light02mini": DeviceType.LIGHT_SL02_MINI,
+    "light03": DeviceType.LIGHT_SL03,
+}
 
 # shared parse
 shared_parser = ArgumentParser(add_help=False)
@@ -83,7 +64,7 @@ shared_parser.add_argument(
     action="store_true",
     help="include the raw message",
 )
-possible_types = [t.value for t in DeviceType]
+possible_types = [t for t in DEVICES]
 shared_parser.add_argument(
     "-c",
     "--device-type",
@@ -125,16 +106,25 @@ shared_parser.add_argument(
 # parent parser
 main_parser = ArgumentParser(
     description="Control your Switcher device",
-    epilog=_examples,
     formatter_class=RawDescriptionHelpFormatter,
 )
 
 subparsers = main_parser.add_subparsers(dest="action", description="supported actions")
 
 # control_thermostat parser
+_control_thermostat_examples = """example usage:
+
+poetry run control_device control_thermostat -c "breeze" -d 3a20b7 -i "192.168.50.77" -r ELEC7001 -s on\n
+poetry run control_device control_thermostat -c "breeze" -d 3a20b7 -i "192.168.50.77" -r ELEC7001 -m cool -f high -t 24\n
+poetry run control_device control_thermostat -c "breeze" -d 3a20b7 -i "192.168.50.77" -r ELEC7001 -m cool -f high -t 24 -u\n
+poetry run control_device control_thermostat -c "breeze" -d 3a20b7 -i "192.168.50.77" -r ELEC7001 -m dry\n
+poetry run control_device control_thermostat -c "breeze" -d 3a20b7 -i "192.168.50.77" -r ELEC7001 -s off\n
+"""  # noqa E501
 control_thermostat_parser = subparsers.add_parser(
     "control_thermostat",
     help="control a breeze device",
+    epilog=_control_thermostat_examples,
+    formatter_class=RawDescriptionHelpFormatter,
     parents=[shared_parser],
 )
 control_thermostat_parser.add_argument(
@@ -183,9 +173,16 @@ control_thermostat_parser.add_argument(
 )
 
 # create_schedule parser
+_create_schedule_examples = """example usage:
+
+poetry run control_device create_schedule -c "touch" -d ab1c2d -i "111.222.11.22" -n "14:00" -f "14:30"\n
+poetry run control_device create_schedule -c "touch" -d ab1c2d -i "111.222.11.22" -n "17:30" -f "18:30" -w Sunday Monday Friday\n
+"""  # noqa E501
 create_schedule_parser = subparsers.add_parser(
     "create_schedule",
     help="create a new schedule",
+    epilog=_create_schedule_examples,
+    formatter_class=RawDescriptionHelpFormatter,
     parents=[shared_parser],
 )
 create_schedule_parser.add_argument(
@@ -214,9 +211,15 @@ create_schedule_parser.add_argument(
 )
 
 # delete_schedule parser
+_delete_schedule_examples = """example usage:
+
+poetry run control_device delete_schedule -c "touch" -d ab1c2d -i "111.222.11.22" -s 3\n
+"""  # noqa E501
 delete_schedule_parser = subparsers.add_parser(
     "delete_schedule",
     help="delete a device schedule",
+    epilog=_delete_schedule_examples,
+    formatter_class=RawDescriptionHelpFormatter,
     parents=[shared_parser],
 )
 delete_schedule_parser.add_argument(
@@ -228,26 +231,54 @@ delete_schedule_parser.add_argument(
 )
 
 # get_schedules parser
+_get_schedules_examples = """example usage:
+
+poetry run control_device get_schedules -c "touch" -d ab1c2d -i "111.222.11.22"\n
+"""  # noqa E501
 subparsers.add_parser(
-    "get_schedules", help="retrieve a device schedules", parents=[shared_parser]
+    "get_schedules",
+    help="retrieve a device schedules",
+    epilog=_get_schedules_examples,
+    formatter_class=RawDescriptionHelpFormatter,
+    parents=[shared_parser],
 )
 
 # get_state parser
+_get_state_examples = """example usage:
+
+poetry run control_device get_state -c "touch" -d ab1c2d -i "111.222.11.22"\n
+"""  # noqa E501
 subparsers.add_parser(
-    "get_state", help="get the current state of a device", parents=[shared_parser]
+    "get_state",
+    help="get the current state of a device",
+    epilog=_get_state_examples,
+    formatter_class=RawDescriptionHelpFormatter,
+    parents=[shared_parser],
 )
 
 # get_thermostat_state parser
+_get_thermostat_state_examples = """example usage:
+
+poetry run control_device get_thermostat_state -c "breeze" -d 3a20b7 -i "192.168.50.77"\n
+"""  # noqa E501
 subparsers.add_parser(
     "get_thermostat_state",
     help="get the current state a thermostat (breeze) device",
+    epilog=_get_thermostat_state_examples,
+    formatter_class=RawDescriptionHelpFormatter,
     parents=[shared_parser],
 )
 
 # set_auto_shutdown parser
+_set_auto_shutdown_examples = """example usage:
+
+poetry run control_device set_auto_shutdown -c "touch" -d ab1c2d -i "111.222.11.22" -r 2 -m 30\n
+"""  # noqa E501
 set_auto_shutdown_parser = subparsers.add_parser(
     "set_auto_shutdown",
     help="set the auto shutdown property (1h-24h)",
+    epilog=_set_auto_shutdown_examples,
+    formatter_class=RawDescriptionHelpFormatter,
     parents=[shared_parser],
 )
 set_auto_shutdown_parser.add_argument(
@@ -267,8 +298,16 @@ set_auto_shutdown_parser.add_argument(
 )
 
 # set_name parser
+_set_name_examples = """example usage:
+
+poetry run control_device set_name -c "touch" -d ab1c2d -i "111.222.11.22" -n "My Boiler"\n
+"""  # noqa E501
 set_name_parser = subparsers.add_parser(
-    "set_name", help="set the name of the device", parents=[shared_parser]
+    "set_name",
+    help="set the name of the device",
+    epilog=_set_name_examples,
+    formatter_class=RawDescriptionHelpFormatter,
+    parents=[shared_parser],
 )
 set_name_parser.add_argument(
     "-n",
@@ -279,9 +318,19 @@ set_name_parser.add_argument(
 )
 
 # get_shutter_state parser
+_get_shutter_state_examples = """example usage:
+
+poetry run control_device get_shutter_state -c "runner" -d f2239a -i "192.168.50.98"\n
+poetry run control_device get_shutter_state -c "runnermini" -d f2239a -i "192.168.50.98"\n
+poetry run control_device get_shutter_state -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98"\n
+poetry run control_device get_shutter_state -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98" -x 0\n
+poetry run control_device get_shutter_state -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98" -x 1\n
+"""  # noqa E501
 get_shutter_state_parser = subparsers.add_parser(
     "get_shutter_state",
     help="get the current shutter state of a device",
+    epilog=_get_shutter_state_examples,
+    formatter_class=RawDescriptionHelpFormatter,
     parents=[shared_parser],
 )
 get_shutter_state_parser.add_argument(
@@ -294,9 +343,19 @@ get_shutter_state_parser.add_argument(
 )
 
 # stop shutter parser
+_set_shutter_position_examples = """example usage:
+
+poetry run control_device set_shutter_position -c "runner" -d f2239a -i "192.168.50.98" -p 50\n
+poetry run control_device set_shutter_position -c "runnermini" -d f2239a -i "192.168.50.98" -p 50\n
+poetry run control_device set_shutter_position -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98" -p 50\n
+poetry run control_device set_shutter_position -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98" -p 50 -x 0\n
+poetry run control_device set_shutter_position -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98" -p 50 -x 1\n
+"""  # noqa E501
 set_shutter_position_parser = subparsers.add_parser(
     "set_shutter_position",
     help="set shutter position",
+    epilog=_set_shutter_position_examples,
+    formatter_class=RawDescriptionHelpFormatter,
     parents=[shared_parser],
 )
 set_shutter_position_parser.add_argument(
@@ -316,8 +375,20 @@ set_shutter_position_parser.add_argument(
 )
 
 # stop shutter parser
+_stop_shutter_examples = """example usage:
+
+poetry run control_device stop_shutter -c "runner" -d f2239a -i "192.168.50.98"\n
+poetry run control_device stop_shutter -c "runnermini" -d f2239a -i "192.168.50.98"\n
+poetry run control_device stop_shutter -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98"\n
+poetry run control_device stop_shutter -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98" -x 0\n
+poetry run control_device stop_shutter -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d f2239a -i "192.168.50.98" -x 1\n
+"""  # noqa E501
 stop_shutter_parser = subparsers.add_parser(
-    "stop_shutter", help="stop shutter", parents=[shared_parser]
+    "stop_shutter",
+    help="stop shutter",
+    epilog=_stop_shutter_examples,
+    formatter_class=RawDescriptionHelpFormatter,
+    parents=[shared_parser],
 )
 stop_shutter_parser.add_argument(
     "-x",
@@ -328,14 +399,83 @@ stop_shutter_parser.add_argument(
     help="the circuit number to operate",
 )
 
+# turn_off_shutter_child_lock parser
+_turn_off_shutter_child_lock_examples = """example usage:
+
+poetry run control_device turn_off_shutter_child_lock -c "runner" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_off_shutter_child_lock -c "runnermini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_off_shutter_child_lock -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device turn_off_shutter_child_lock -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device turn_off_shutter_child_lock -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+"""  # noqa E501
+turn_off_shutter_child_lock_parser = subparsers.add_parser(
+    "turn_off_shutter_child_lock",
+    help="turn off shutter child lock",
+    epilog=_turn_off_shutter_child_lock_examples,
+    formatter_class=RawDescriptionHelpFormatter,
+    parents=[shared_parser],
+)
+turn_off_shutter_child_lock_parser.add_argument(
+    "-x",
+    "--index",
+    required=False,
+    type=int,
+    default=0,
+    help="the circuit number to turn off",
+)
+
+# turn_on_shutter_child_lock parser
+_turn_on_shutter_child_lock_examples = """example usage:
+
+poetry run control_device turn_on_shutter_child_lock -c "runner" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_on_shutter_child_lock -c "runnermini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_on_shutter_child_lock -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device turn_on_shutter_child_lock -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device turn_on_shutter_child_lock -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+"""  # noqa E501
+turn_on_shutter_child_lock_parser = subparsers.add_parser(
+    "turn_on_shutter_child_lock",
+    help="turn on shutter child lock",
+    epilog=_turn_on_shutter_child_lock_examples,
+    formatter_class=RawDescriptionHelpFormatter,
+    parents=[shared_parser],
+)
+turn_on_shutter_child_lock_parser.add_argument(
+    "-x",
+    "--index",
+    required=False,
+    type=int,
+    default=0,
+    help="the circuit number to turn on",
+)
+
 # turn_off parser
-turn_on_parser = subparsers.add_parser(
-    "turn_off", help="turn off the device", parents=[shared_parser]
+_turn_off_examples = """example usage:
+
+poetry run control_device turn_off -c "touch" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_off -c "touch" -d ab1c2d -l 18 -i "111.222.11.22"\n
+"""  # noqa E501
+turn_off_parser = subparsers.add_parser(
+    "turn_off",
+    help="turn off the device",
+    epilog=_turn_off_examples,
+    formatter_class=RawDescriptionHelpFormatter,
+    parents=[shared_parser],
 )
 
 # turn_on parser
+_turn_on_examples = """example usage:
+
+poetry run control_device turn_on -c "touch" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_on -c "touch" -d ab1c2d -l 18 -i "111.222.11.22"\n
+poetry run control_device turn_on -c "touch" -d ab1c2d -i "111.222.11.22" -t 15\n
+"""  # noqa E501
 turn_on_parser = subparsers.add_parser(
-    "turn_on", help="turn on the device", parents=[shared_parser]
+    "turn_on",
+    help="turn on the device",
+    epilog=_turn_on_examples,
+    formatter_class=RawDescriptionHelpFormatter,
+    parents=[shared_parser],
 )
 turn_on_parser.add_argument(
     "-t",
@@ -347,9 +487,26 @@ turn_on_parser.add_argument(
 )
 
 # get_light_state parser
+_get_light_state_examples = """example usage:
+
+poetry run control_device get_light_state -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device get_light_state -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device get_light_state -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device get_light_state -c "light01" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device get_light_state -c "light01mini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device get_light_state -c "light02" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device get_light_state -c "light02" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device get_light_state -c "light02mini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device get_light_state -c "light02mini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device get_light_state -c "light03" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device get_light_state -c "light03" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device get_light_state -c "light03" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 2\n
+"""  # noqa E501
 get_light_state_parser = subparsers.add_parser(
     "get_light_state",
     help="get the current light state of a device",
+    epilog=_get_light_state_examples,
+    formatter_class=RawDescriptionHelpFormatter,
     parents=[shared_parser],
 )
 get_light_state_parser.add_argument(
@@ -362,10 +519,29 @@ get_light_state_parser.add_argument(
 )
 
 # turn_off_light parser
-turn_on_light_parser = subparsers.add_parser(
-    "turn_off_light", help="turn off light", parents=[shared_parser]
+_turn_off_light_examples = """example usage:
+
+poetry run control_device turn_off_light -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device turn_off_light -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device turn_off_light -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_off_light -c "light01" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_off_light -c "light01mini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_off_light -c "light02" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device turn_off_light -c "light02" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device turn_off_light -c "light02mini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device turn_off_light -c "light02mini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device turn_off_light -c "light03" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device turn_off_light -c "light03" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device turn_off_light -c "light03" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 2\n
+"""  # noqa E501
+turn_off_light_parser = subparsers.add_parser(
+    "turn_off_light",
+    help="turn off light",
+    epilog=_turn_off_light_examples,
+    formatter_class=RawDescriptionHelpFormatter,
+    parents=[shared_parser],
 )
-turn_on_light_parser.add_argument(
+turn_off_light_parser.add_argument(
     "-x",
     "--index",
     required=False,
@@ -375,8 +551,27 @@ turn_on_light_parser.add_argument(
 )
 
 # turn_on_light parser
+_turn_on_light_examples = """example usage:
+
+poetry run control_device turn_on_light -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device turn_on_light -c "runners11" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device turn_on_light -c "runners12" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_on_light -c "light01" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_on_light -c "light01mini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22"\n
+poetry run control_device turn_on_light -c "light02" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device turn_on_light -c "light02" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device turn_on_light -c "light02mini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device turn_on_light -c "light02mini" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device turn_on_light -c "light03" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 0\n
+poetry run control_device turn_on_light -c "light03" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 1\n
+poetry run control_device turn_on_light -c "light03" -k "zvVvd7JxtN7CgvkD1Psujw==" -d ab1c2d -i "111.222.11.22" -x 2\n
+"""  # noqa E501
 turn_on_light_parser = subparsers.add_parser(
-    "turn_on_light", help="turn on light", parents=[shared_parser]
+    "turn_on_light",
+    help="turn on light",
+    epilog=_turn_on_light_examples,
+    formatter_class=RawDescriptionHelpFormatter,
+    parents=[shared_parser],
 )
 turn_on_light_parser.add_argument(
     "-x",
@@ -406,9 +601,7 @@ async def get_thermostat_state(
     token: Union[str, None] = None,
 ) -> None:
     """Use to launch a get_breeze_state request."""
-    async with SwitcherType2Api(
-        device_type, device_ip, device_id, device_key, token
-    ) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key, token) as api:
         printer.pprint(asdict(await api.get_breeze_state(), verbose))
 
 
@@ -422,9 +615,7 @@ async def get_shutter_state(
     token: Union[str, None] = None,
 ) -> None:
     """Use to launch a get_shutter_state request."""
-    async with SwitcherType2Api(
-        device_type, device_ip, device_id, device_key, token
-    ) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key, token) as api:
         printer.pprint(asdict(await api.get_shutter_state(index), verbose))
 
 
@@ -436,7 +627,7 @@ async def get_state(
     verbose: bool,
 ) -> None:
     """Use to launch a get_state request."""
-    async with SwitcherType1Api(device_type, device_ip, device_id, device_key) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key) as api:
         printer.pprint(asdict(await api.get_state(), verbose))
 
 
@@ -456,9 +647,7 @@ async def control_thermostat(
     token: Union[str, None] = None,
 ) -> None:
     """Control Breeze device."""
-    async with SwitcherType2Api(
-        device_type, device_ip, device_id, device_key, token
-    ) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key, token) as api:
         printer.pprint(
             asdict(
                 await api.control_breeze_device(
@@ -484,7 +673,7 @@ async def turn_on(
     verbose: bool,
 ) -> None:
     """Use to launch a turn_on request."""
-    async with SwitcherType1Api(device_type, device_ip, device_id, device_key) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key) as api:
         printer.pprint(asdict(await api.control_device(Command.ON, timer), verbose))
 
 
@@ -496,7 +685,7 @@ async def turn_off(
     verbose: bool,
 ) -> None:
     """Use to launch a turn_off request."""
-    async with SwitcherType1Api(device_type, device_ip, device_id, device_key) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key) as api:
         printer.pprint(asdict(await api.control_device(Command.OFF), verbose))
 
 
@@ -509,7 +698,7 @@ async def set_name(
     verbose: bool,
 ) -> None:
     """Use to launch a set_name request."""
-    async with SwitcherType1Api(device_type, device_ip, device_id, device_key) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key) as api:
         printer.pprint(asdict(await api.set_device_name(name), verbose))
 
 
@@ -524,7 +713,7 @@ async def set_auto_shutdown(
 ) -> None:
     """Use to launch a set_auto_shutdown request."""
     td_val = timedelta(hours=hours, minutes=minutes)
-    async with SwitcherType1Api(device_type, device_ip, device_id, device_key) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key) as api:
         printer.pprint(asdict(await api.set_auto_shutdown(td_val), verbose))
 
 
@@ -536,7 +725,7 @@ async def get_schedules(
     verbose: bool,
 ) -> None:
     """Use to launch a get_schedules request."""
-    async with SwitcherType1Api(device_type, device_ip, device_id, device_key) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key) as api:
         response = await api.get_schedules()
         if verbose:
             printer.pprint({"unparsed_response": response.unparsed_response})
@@ -555,7 +744,7 @@ async def delete_schedule(
     verbose: bool,
 ) -> None:
     """Use to launch a delete_schedule request."""
-    async with SwitcherType1Api(device_type, device_ip, device_id, device_key) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key) as api:
         printer.pprint(asdict(await api.delete_schedule(schedule_id), verbose))
 
 
@@ -570,7 +759,7 @@ async def create_schedule(
     verbose: bool,
 ) -> None:
     """Use to launch a create_schedule request."""
-    async with SwitcherType1Api(device_type, device_ip, device_id, device_key) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key) as api:
         printer.pprint(
             asdict(
                 await api.create_schedule(
@@ -593,9 +782,7 @@ async def stop_shutter(
     token: Union[str, None] = None,
 ) -> None:
     """Stop shutter."""
-    async with SwitcherType2Api(
-        device_type, device_ip, device_id, device_key, token
-    ) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key, token) as api:
         printer.pprint(
             asdict(
                 await api.stop_shutter(index),
@@ -615,9 +802,7 @@ async def set_shutter_position(
     token: Union[str, None] = None,
 ) -> None:
     """Use to set the shutter position."""
-    async with SwitcherType2Api(
-        device_type, device_ip, device_id, device_key, token
-    ) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key, token) as api:
         printer.pprint(
             asdict(
                 await api.set_position(position, index),
@@ -626,6 +811,42 @@ async def set_shutter_position(
         )
 
 
+async def turn_on_shutter_child_lock(
+    device_type: DeviceType,
+    device_id: str,
+    device_key: str,
+    device_ip: str,
+    index: int,
+    verbose: bool,
+    token: Union[str, None] = None,
+) -> None:
+    """Use for turn on shutter child lock."""
+    async with SwitcherApi(device_type, device_ip, device_id, device_key, token) as api:
+        printer.pprint(
+            asdict(
+                await api.set_shutter_child_lock(ShutterChildLock.ON, index), verbose
+            )
+        )
+
+
+async def turn_off_shutter_child_lock(
+    device_type: DeviceType,
+    device_id: str,
+    device_key: str,
+    device_ip: str,
+    index: int,
+    verbose: bool,
+    token: Union[str, None] = None,
+) -> None:
+    """Use for turn off shutter child lock."""
+    async with SwitcherApi(device_type, device_ip, device_id, device_key, token) as api:
+        printer.pprint(
+            asdict(
+                await api.set_shutter_child_lock(ShutterChildLock.OFF, index), verbose
+            )
+        )
+
+
 async def get_light_state(
     device_type: DeviceType,
     device_id: str,
@@ -636,9 +857,7 @@ async def get_light_state(
     token: Union[str, None] = None,
 ) -> None:
     """Use to launch a get_light_state request."""
-    async with SwitcherType2Api(
-        device_type, device_ip, device_id, device_key, token
-    ) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key, token) as api:
         printer.pprint(asdict(await api.get_light_state(index), verbose))
 
 
@@ -652,9 +871,7 @@ async def turn_on_light(
     token: Union[str, None] = None,
 ) -> None:
     """Use for turn on light."""
-    async with SwitcherType2Api(
-        device_type, device_ip, device_id, device_key, token
-    ) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key, token) as api:
         printer.pprint(asdict(await api.set_light(DeviceState.ON, index), verbose))
 
 
@@ -668,9 +885,7 @@ async def turn_off_light(
     token: Union[str, None] = None,
 ) -> None:
     """Use for turn off light."""
-    async with SwitcherType2Api(
-        device_type, device_ip, device_id, device_key, token
-    ) as api:
+    async with SwitcherApi(device_type, device_ip, device_id, device_key, token) as api:
         printer.pprint(asdict(await api.set_light(DeviceState.OFF, index), verbose))
 
 
@@ -680,12 +895,14 @@ def main() -> None:
         args = main_parser.parse_args()
 
         if "device_type" in args and type(args.device_type) is not DeviceType:
-            args.device_type = convert_str_to_devicetype(args.device_type)
+            device_type = DEVICES[args.device_type.lower()]
+        else:
+            device_type = args.device_type
 
         if args.action == "get_state":
             asyncio.run(
                 get_state(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -695,7 +912,7 @@ def main() -> None:
         elif args.action == "turn_on":
             asyncio.run(
                 turn_on(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -706,7 +923,7 @@ def main() -> None:
         elif args.action == "turn_off":
             asyncio.run(
                 turn_off(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -716,7 +933,7 @@ def main() -> None:
         elif args.action == "set_name":
             asyncio.run(
                 set_name(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -727,7 +944,7 @@ def main() -> None:
         elif args.action == "set_auto_shutdown":
             asyncio.run(
                 set_auto_shutdown(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -739,7 +956,7 @@ def main() -> None:
         elif args.action == "get_schedules":
             asyncio.run(
                 get_schedules(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -749,7 +966,7 @@ def main() -> None:
         elif args.action == "delete_schedule":
             asyncio.run(
                 delete_schedule(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -760,7 +977,7 @@ def main() -> None:
         elif args.action == "create_schedule":
             asyncio.run(
                 create_schedule(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -774,7 +991,7 @@ def main() -> None:
         elif args.action == "get_shutter_state":
             asyncio.run(
                 get_shutter_state(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -787,7 +1004,7 @@ def main() -> None:
         elif args.action == "stop_shutter":
             asyncio.run(
                 stop_shutter(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -800,7 +1017,7 @@ def main() -> None:
         elif args.action == "set_shutter_position":
             asyncio.run(
                 set_shutter_position(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -811,10 +1028,36 @@ def main() -> None:
                 )
             )
 
+        elif args.action == "turn_on_shutter_child_lock":
+            asyncio.run(
+                turn_on_shutter_child_lock(
+                    device_type,
+                    args.device_id,
+                    args.device_key,
+                    args.ip_address,
+                    args.index,
+                    args.verbose,
+                    args.token,
+                )
+            )
+
+        elif args.action == "turn_off_shutter_child_lock":
+            asyncio.run(
+                turn_off_shutter_child_lock(
+                    device_type,
+                    args.device_id,
+                    args.device_key,
+                    args.ip_address,
+                    args.index,
+                    args.verbose,
+                    args.token,
+                )
+            )
+
         elif args.action == "control_thermostat":
             asyncio.run(
                 control_thermostat(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -832,7 +1075,7 @@ def main() -> None:
         elif args.action == "get_thermostat_state":
             asyncio.run(
                 get_thermostat_state(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -844,7 +1087,7 @@ def main() -> None:
         elif args.action == "get_light_state":
             asyncio.run(
                 get_light_state(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -857,7 +1100,7 @@ def main() -> None:
         elif args.action == "turn_on_light":
             asyncio.run(
                 turn_on_light(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
@@ -870,7 +1113,7 @@ def main() -> None:
         elif args.action == "turn_off_light":
             asyncio.run(
                 turn_off_light(
-                    args.device_type,
+                    device_type,
                     args.device_id,
                     args.device_key,
                     args.ip_address,
