@@ -14,7 +14,6 @@
 
 """Switcher integration TCP socket API module."""
 
-from abc import ABC
 from asyncio import open_connection
 from binascii import unhexlify
 from datetime import timedelta
@@ -25,9 +24,9 @@ from types import TracebackType
 from typing import Optional, Set, Tuple, Type, Union, final
 
 from ..device import (
-    DeviceCategory,
     DeviceState,
     DeviceType,
+    ShutterChildLock,
     ThermostatFanLevel,
     ThermostatMode,
     ThermostatSwing,
@@ -64,14 +63,6 @@ SWITCHER_TCP_PORT_TYPE1 = 9957
 # Type 2 devices: Breeze, Runners
 SWITCHER_TCP_PORT_TYPE2 = 10000
 
-SWITCHER_DEVICE_TO_TCP_PORT = {
-    DeviceCategory.THERMOSTAT: SWITCHER_TCP_PORT_TYPE2,
-    DeviceCategory.SHUTTER: SWITCHER_TCP_PORT_TYPE2,
-    DeviceCategory.SINGLE_SHUTTER_DUAL_LIGHT: SWITCHER_TCP_PORT_TYPE2,
-    DeviceCategory.WATER_HEATER: SWITCHER_TCP_PORT_TYPE1,
-    DeviceCategory.POWER_PLUG: SWITCHER_TCP_PORT_TYPE1,
-}
-
 
 @unique
 class Command(Enum):
@@ -81,7 +72,8 @@ class Command(Enum):
     OFF = "0"
 
 
-class SwitcherApi(ABC):
+@final
+class SwitcherApi:
     """Switcher TCP based API.
 
     Args:
@@ -89,7 +81,6 @@ class SwitcherApi(ABC):
         ip_address: the ip address assigned to the device.
         device_id: the id of the desired device.
         device_key: the login key of the device.
-        port: the port of the device, default is 9957.
 
     """
 
@@ -99,7 +90,6 @@ class SwitcherApi(ABC):
         ip_address: str,
         device_id: str,
         device_key: str,
-        port: int = SWITCHER_TCP_PORT_TYPE1,
         token: Union[str, None] = None,
     ) -> None:
         """Initialize the Switcher TCP connection API."""
@@ -107,7 +97,9 @@ class SwitcherApi(ABC):
         self._ip_address = ip_address
         self._device_id = device_id
         self._device_key = device_key
-        self._port = port
+        self._port = SWITCHER_TCP_PORT_TYPE1
+        if device_type.protocol_type == 2:
+            self._port = SWITCHER_TCP_PORT_TYPE2
         self._connected = False
         self._token = None
         if self._device_type.token_needed:
@@ -161,6 +153,24 @@ class SwitcherApi(ABC):
             logger.info("switcher device not connected")
         self._connected = False
 
+    async def _send_packet(self, packet_id: str, packet: str) -> bytes:
+        """Sign and send a packet, then read the response.
+
+        Args:
+            packet_id (str): The identifier for the packet being sent.
+            packet (str): The packet to be sent.
+
+        Returns:
+            bytes: The response from the device.
+        """
+        packet = set_message_length(packet)
+        signed_packet = sign_packet_with_crc_key(packet)
+
+        logger.debug(f"sending a {packet_id} packet")
+        self._writer.write(unhexlify(signed_packet))
+        response = await self._reader.read(1024)
+        return response
+
     async def _login(self) -> Tuple[str, SwitcherLoginResponse]:
         """Use for sending the login packet to the device.
 
@@ -185,232 +195,16 @@ class SwitcherApi(ABC):
             packet = packets.LOGIN_PACKET_TYPE2.format(timestamp, self._device_id)
         else:
             packet = packets.LOGIN_PACKET_TYPE1.format(timestamp, self._device_key)
-        signed_packet = sign_packet_with_crc_key(packet)
 
-        logger.debug("sending a login packet")
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        response = await self._send_packet("login", packet)
 
         if bool(self._token):
             packet = packets.LOGIN2_TOKEN_PACKET_TYPE2.format(
                 self._device_id, timestamp, self._token
             )
-            signed_packet = sign_packet_with_crc_key(packet)
-            logger.debug("sending a login2 packet")
-            self._writer.write(unhexlify(signed_packet))
-            response = await self._reader.read(1024)
+            response = await self._send_packet("login2", packet)
         return timestamp, SwitcherLoginResponse(response)
 
-    async def get_state(self) -> SwitcherStateResponse:
-        """Use for sending the get state packet to the device.
-
-        Returns:
-            An instance of ``SwitcherStateResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def get_breeze_state(self) -> SwitcherThermostatStateResponse:
-        """Use for sending the get state packet to the Breeze device.
-
-        Returns:
-            An instance of ``SwitcherThermostatStateResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def control_device(
-        self, command: Command, minutes: int = 0
-    ) -> SwitcherBaseResponse:
-        """Use for sending the control packet to the device.
-
-        Args:
-            command: use the ``aioswitcher.api.Command`` enum.
-            minutes: if turning-on optionally incorporate a timer.
-
-        Returns:
-            An instance of ``SwitcherBaseResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def control_breeze_device(
-        self,
-        remote: SwitcherBreezeRemote,
-        state: Union[DeviceState, None] = None,
-        mode: Union[ThermostatMode, None] = None,
-        target_temp: int = 0,
-        fan_level: Union[ThermostatFanLevel, None] = None,
-        swing: Union[ThermostatSwing, None] = None,
-        update_state: bool = False,
-    ) -> SwitcherBaseResponse:
-        """Use for sending the control packet to the Breeze device.
-
-        Args:
-            remote: the remote for the breeze device
-            state: the desired state of the device
-            mode: the desired mode of the device
-            target_temp: the target temperature
-            fan_level: the desired fan level
-            swing: the desired swing state
-            update_state: update the device state without controlling the device
-
-        Returns:
-            An instance of ``SwitcherBaseResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def stop_shutter(self, index: int = 0) -> SwitcherBaseResponse:
-        """Use for stopping the shutter.
-
-        Args:
-            index: which runner to stop position, default to 0.
-
-        Returns:
-            An instance of ``SwitcherBaseResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def set_position(
-        self, position: int = 0, index: int = 0
-    ) -> SwitcherBaseResponse:
-        """Use for setting the shutter position of the Runners devices.
-
-        Args:
-            position: the position to set the device to, default to 0.
-            index: which runner to set position, default to 0.
-
-        Returns:
-            An instance of ``SwitcherBaseResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def get_shutter_state(self, index: int = 0) -> SwitcherBaseResponse:
-        """Use for sending the get state packet to the Runners devices.
-
-        Args:
-            index: which runner to set get state, default to 0.
-
-        Returns:
-            An instance of ``SwitcherShutterStateResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def set_device_name(self, name: str) -> SwitcherBaseResponse:
-        """Use for sending the set name packet to the device.
-
-        Args:
-            name: string name with the length of 2 >= x >= 32.
-
-        Returns:
-            An instance of ``SwitcherBaseResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def set_auto_shutdown(self, full_time: timedelta) -> SwitcherBaseResponse:
-        """Use for sending the set auto-off packet to the device.
-
-        Args:
-            full_time: timedelta value containing the configuration value for
-                auto-shutdown.
-
-        Returns:
-            An instance of ``SwitcherBaseResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def get_schedules(self) -> SwitcherGetSchedulesResponse:
-        """Use for retrieval of the schedules from the device.
-
-        Returns:
-            An instance of ``SwitcherGetSchedulesResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def delete_schedule(self, schedule_id: str) -> SwitcherBaseResponse:
-        """Use for deleting a schedule from the device.
-
-        Use ``get_schedules`` to retrieve the schedule instance.
-
-        Args:
-            schedule_id: the identification of the schedule for deletion.
-
-        Returns:
-            An instance of ``SwitcherBaseResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def create_schedule(
-        self, start_time: str, end_time: str, days: Set[Days] = set()
-    ) -> SwitcherBaseResponse:
-        """Use for creating a new schedule in the next empty schedule slot.
-
-        Args:
-            start_time: a string start time in %H:%M format. e.g. 13:00.
-            end_time: a string start time in %H:%M format. e.g. 13:00.
-            days: for recurring schedules, add ``Days``.
-
-        Returns:
-            An instance of ``SwitcherBaseResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def get_light_state(self, index: int = 0) -> SwitcherBaseResponse:
-        """Use for sending the get state packet to the Light devices.
-
-        Args:
-            index: which light to set get state, default to 0.
-
-        Returns:
-            An instance of ``SwitcherLightStateResponse``.
-
-        """
-        raise NotImplementedError
-
-    async def set_light(
-        self, command: DeviceState, index: int = 0
-    ) -> SwitcherBaseResponse:
-        """Use for turn on/off light.
-
-        Args:
-            command: use the ``aioswitcher.api.DeviceState`` enum.
-            index: which light to turn on/off, default to 0.
-
-        Returns:
-            An instance of ``SwitcherBaseResponse``.
-
-        """
-        raise NotImplementedError
-
-
-@final
-class SwitcherType1Api(SwitcherApi):
-    """Switcher Type1 devices (Plug, V2, Touch, V4) TCP based API.
-
-    Args:
-        device_type: the type of the device.
-        ip_address: the ip address assigned to the device.
-        device_id: the id of the desired device.
-        device_key: the login key of the device.
-    """
-
-    def __init__(
-        self, device_type: DeviceType, ip_address: str, device_id: str, device_key: str
-    ) -> None:
-        """Initialize the Switcher TCP connection API."""
-        super().__init__(
-            device_type, ip_address, device_id, device_key, SWITCHER_TCP_PORT_TYPE1
-        )
-
     async def get_state(self) -> SwitcherStateResponse:
         """Use for sending the get state packet to the device.
 
@@ -423,11 +217,7 @@ class SwitcherType1Api(SwitcherApi):
             packet = packets.GET_STATE_PACKET_TYPE1.format(
                 login_resp.session_id, timestamp, self._device_id
             )
-            signed_packet = sign_packet_with_crc_key(packet)
-
-            logger.debug("sending a get state packet")
-            self._writer.write(unhexlify(signed_packet))
-            state_resp = await self._reader.read(1024)
+            state_resp = await self._send_packet("get state", packet)
             try:
                 response = SwitcherStateResponse(state_resp)
                 if response.successful:
@@ -462,11 +252,7 @@ class SwitcherType1Api(SwitcherApi):
             command.value,
             timer,
         )
-        signed_packet = sign_packet_with_crc_key(packet)
-
-        logger.debug("sending a control packet")
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        response = await self._send_packet("control", packet)
         return SwitcherBaseResponse(response)
 
     async def set_auto_shutdown(self, full_time: timedelta) -> SwitcherBaseResponse:
@@ -488,11 +274,7 @@ class SwitcherType1Api(SwitcherApi):
             self._device_id,
             auto_shutdown,
         )
-        signed_packet = sign_packet_with_crc_key(packet)
-
-        logger.debug("sending a set auto shutdown packet")
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        response = await self._send_packet("set auto shutdown", packet)
         return SwitcherBaseResponse(response)
 
     async def set_device_name(self, name: str) -> SwitcherBaseResponse:
@@ -513,11 +295,7 @@ class SwitcherType1Api(SwitcherApi):
             self._device_id,
             device_name,
         )
-        signed_packet = sign_packet_with_crc_key(packet)
-
-        logger.debug("sending a set name packet")
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        response = await self._send_packet("set name", packet)
         return SwitcherBaseResponse(response)
 
     async def get_schedules(self) -> SwitcherGetSchedulesResponse:
@@ -533,11 +311,7 @@ class SwitcherType1Api(SwitcherApi):
             timestamp,
             self._device_id,
         )
-        signed_packet = sign_packet_with_crc_key(packet)
-
-        logger.debug("sending a get schedules packet")
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        response = await self._send_packet("get schedules", packet)
         return SwitcherGetSchedulesResponse(response)
 
     async def delete_schedule(self, schedule_id: str) -> SwitcherBaseResponse:
@@ -556,11 +330,7 @@ class SwitcherType1Api(SwitcherApi):
         packet = packets.DELETE_SCHEDULE_PACKET.format(
             login_resp.session_id, timestamp, self._device_id, schedule_id
         )
-        signed_packet = sign_packet_with_crc_key(packet)
-
-        logger.debug("sending a delete schedule packet")
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        response = await self._send_packet("delete schedule", packet)
         return SwitcherBaseResponse(response)
 
     async def create_schedule(
@@ -595,43 +365,9 @@ class SwitcherType1Api(SwitcherApi):
             self._device_id,
             new_schedule,
         )
-        signed_packet = sign_packet_with_crc_key(packet)
-
-        logger.debug("sending a create schedule packet")
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        response = await self._send_packet("create schedule", packet)
         return SwitcherBaseResponse(response)
 
-
-@final
-class SwitcherType2Api(SwitcherApi):
-    """Switcher Type2 devices (Breeze, Runners) TCP based API.
-
-    Args:
-        device_type: the type of the device.
-        ip_address: the ip address assigned to the device.
-        device_id: the id of the desired device.
-        device_key: the login key of the device.
-    """
-
-    def __init__(
-        self,
-        device_type: DeviceType,
-        ip_address: str,
-        device_id: str,
-        device_key: str,
-        token: Union[str, None] = None,
-    ) -> None:
-        """Initialize the Switcher TCP connection API."""
-        super().__init__(
-            device_type,
-            ip_address,
-            device_id,
-            device_key,
-            SWITCHER_TCP_PORT_TYPE2,
-            token,
-        )
-
     async def control_breeze_device(
         self,
         remote: SwitcherBreezeRemote,
@@ -698,7 +434,7 @@ class SwitcherType2Api(SwitcherApi):
                     fan_level.value,
                     set_swing.value,
                 )
-                logger.debug("sending a set status packet")
+                response = await self._send_packet("set status", packet)
             else:
                 command = remote.build_command(
                     state, mode, target_temp, fan_level, set_swing, current_state.state
@@ -711,13 +447,7 @@ class SwitcherType2Api(SwitcherApi):
                     command.length,
                     command.command,
                 )
-                logger.debug("sending a control packet")
-
-            packet = set_message_length(packet)
-            signed_packet = sign_packet_with_crc_key(packet)
-
-            self._writer.write(unhexlify(signed_packet))
-            response = await self._reader.read(1024)
+                response = await self._send_packet("control", packet)
             cmd_response = SwitcherBaseResponse(response)
 
             if not cmd_response.successful:
@@ -762,13 +492,7 @@ class SwitcherType2Api(SwitcherApi):
             command.command,
         )
 
-        packet = set_message_length(packet)
-        signed_packet = sign_packet_with_crc_key(packet)
-
-        logger.debug("sending a control packet")
-
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        response = await self._send_packet("control", packet)
         return SwitcherBaseResponse(response)
 
     async def stop_shutter(self, index: int = 0) -> SwitcherBaseResponse:
@@ -808,13 +532,7 @@ class SwitcherType2Api(SwitcherApi):
                 login_resp.session_id, timestamp, self._device_id
             )
 
-        packet = set_message_length(packet)
-        signed_packet = sign_packet_with_crc_key(packet)
-
-        logger.debug("sending a stop control packet")
-
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        response = await self._send_packet("stop control", packet)
         return SwitcherBaseResponse(response)
 
     async def set_position(
@@ -858,13 +576,50 @@ class SwitcherType2Api(SwitcherApi):
                 login_resp.session_id, timestamp, self._device_id, hex_pos
             )
 
-        packet = set_message_length(packet)
-        signed_packet = sign_packet_with_crc_key(packet)
+        response = await self._send_packet("control", packet)
+        return SwitcherBaseResponse(response)
 
-        logger.debug("sending a control packet")
+    async def set_shutter_child_lock(
+        self, command: ShutterChildLock, index: int = 0
+    ) -> SwitcherBaseResponse:
+        """Use for turn on/off shutter child lock.
 
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        Args:
+            command: use the ``aioswitcher.api.ShutterChildLock`` enum.
+            index: which shutter child lock to turn on/off, default to 0.
+
+        Returns:
+            An instance of ``SwitcherBaseResponse``.
+
+        """
+        index_packet = get_shutter_api_packet_index(self._device_type, index)
+        hex_pos = command.value
+
+        logger.debug("about to send set shutter child lock command")
+        timestamp, login_resp = await self._login()
+        if not login_resp.successful:
+            logger.error("Failed to log into device with id %s", self._device_id)
+            raise RuntimeError("login request was not successful")
+
+        logger.debug(
+            "logged in session_id=%s, timestamp=%s", login_resp.session_id, timestamp
+        )
+
+        if bool(self._token):
+            hex_pos = f"0{index_packet}{command.value}"
+            packet = packets.GENERAL_TOKEN_COMMAND.format(
+                timestamp,
+                self._device_id,
+                self._token,
+                packets.SET_CHILD_LOCK_PRECOMMAND,
+                hex_pos,
+            )
+        else:
+            packet = packets.RUNNER_SET_CHILD_LOCK.format(
+                login_resp.session_id, timestamp, self._device_id, hex_pos
+            )
+
+        response = await self._send_packet("control", packet)
         return SwitcherBaseResponse(response)
 
     async def get_breeze_state(self) -> SwitcherThermostatStateResponse:
@@ -886,11 +641,7 @@ class SwitcherType2Api(SwitcherApi):
             login_resp.session_id, timestamp, self._device_id
         )
 
-        signed_packet = sign_packet_with_crc_key(packet)
-
-        logger.debug("sending a get state packet")
-        self._writer.write(unhexlify(signed_packet))
-        state_resp = await self._reader.read(1024)
+        state_resp = await self._send_packet("get state", packet)
         try:
             response = SwitcherThermostatStateResponse(state_resp)
             return response
@@ -913,11 +664,7 @@ class SwitcherType2Api(SwitcherApi):
                 login_resp.session_id, timestamp, self._device_id
             )
 
-            signed_packet = sign_packet_with_crc_key(packet)
-
-            logger.debug("sending a get state packet")
-            self._writer.write(unhexlify(signed_packet))
-            state_resp = await self._reader.read(1024)
+            state_resp = await self._send_packet("get state", packet)
             try:
                 response = SwitcherShutterStateResponse(
                     state_resp, self._device_type, index
@@ -945,11 +692,7 @@ class SwitcherType2Api(SwitcherApi):
                 login_resp.session_id, timestamp, self._device_id
             )
 
-            signed_packet = sign_packet_with_crc_key(packet)
-
-            logger.debug("sending a get state packet")
-            self._writer.write(unhexlify(signed_packet))
-            state_resp = await self._reader.read(1024)
+            state_resp = await self._send_packet("get state", packet)
             try:
                 response = SwitcherLightStateResponse(
                     state_resp, self._device_type, index
@@ -997,11 +740,5 @@ class SwitcherType2Api(SwitcherApi):
             logger.error("Failed to set light device with id %s", self._device_id)
             raise RuntimeError("a token is needed but missing or not valid")
 
-        packet = set_message_length(packet)
-        signed_packet = sign_packet_with_crc_key(packet)
-
-        logger.debug("sending a control packet")
-
-        self._writer.write(unhexlify(signed_packet))
-        response = await self._reader.read(1024)
+        response = await self._send_packet("control", packet)
         return SwitcherBaseResponse(response)
