@@ -22,15 +22,18 @@ from logging import getLogger
 from socket import AF_INET, inet_ntoa
 from struct import pack
 from types import TracebackType
-from typing import Any, Callable, Dict, List, Optional, Tuple, Type, final
+from typing import Any, Callable, Dict, Optional, Tuple, Type, final
 from warnings import warn
 
 from .device import (
     DeviceCategory,
     DeviceState,
     DeviceType,
+    ShutterChildLock,
     ShutterDirection,
     SwitcherBase,
+    SwitcherDualShutterSingleLight,
+    SwitcherLight,
     SwitcherPowerPlug,
     SwitcherShutter,
     SwitcherSingleShutterDualLight,
@@ -54,17 +57,17 @@ logger = getLogger(__name__)
 # Protocol type 1 devices: V2, Touch, V4, Mini, Power Plug
 SWITCHER_UDP_PORT_TYPE1 = 20002
 SWITCHER_UDP_PORT_TYPE1_NEW_VERSION = 10002
-# Protocol type 2 devices: Breeze, Runner, Runner Mini, Runner S11
+# Protocol type 2 devices: Breeze, Runner, Runner Mini, Runner S11, Runner S12
 SWITCHER_UDP_PORT_TYPE2 = 20003
 SWITCHER_UDP_PORT_TYPE2_NEW_VERSION = 10003
 
-SWITCHER_DEVICE_TO_UDP_PORT = {
-    DeviceCategory.WATER_HEATER: SWITCHER_UDP_PORT_TYPE1,
-    DeviceCategory.POWER_PLUG: SWITCHER_UDP_PORT_TYPE1,
-    DeviceCategory.THERMOSTAT: SWITCHER_UDP_PORT_TYPE2,
-    DeviceCategory.SHUTTER: SWITCHER_UDP_PORT_TYPE2,
-    DeviceCategory.SINGLE_SHUTTER_DUAL_LIGHT: SWITCHER_UDP_PORT_TYPE2_NEW_VERSION,
-}
+# List of all the broadcast ports for all the devices
+SWITCHER_UDP_BROADCAST_PORTS = [
+    SWITCHER_UDP_PORT_TYPE1,
+    SWITCHER_UDP_PORT_TYPE1_NEW_VERSION,
+    SWITCHER_UDP_PORT_TYPE2,
+    SWITCHER_UDP_PORT_TYPE2_NEW_VERSION,
+]
 
 
 def _parse_device_from_datagram(
@@ -147,12 +150,21 @@ def _parse_device_from_datagram(
                     parser.get_mac_type2(),
                     parser.get_name(),
                     device_type.token_needed,
-                    parser.get_shutter_position(
-                        get_shutter_discovery_packet_index(device_type, 0)
-                    ),
-                    parser.get_shutter_direction(
-                        get_shutter_discovery_packet_index(device_type, 0)
-                    ),
+                    [
+                        parser.get_shutter_position(
+                            get_shutter_discovery_packet_index(device_type, 0)
+                        )
+                    ],
+                    [
+                        parser.get_shutter_direction(
+                            get_shutter_discovery_packet_index(device_type, 0)
+                        )
+                    ],
+                    [
+                        parser.get_shutter_child_lock(
+                            get_shutter_discovery_packet_index(device_type, 0)
+                        )
+                    ],
                 )
             )
 
@@ -171,12 +183,21 @@ def _parse_device_from_datagram(
                     parser.get_mac_type2(),
                     parser.get_name(),
                     device_type.token_needed,
-                    parser.get_shutter_position(
-                        get_shutter_discovery_packet_index(device_type, 0)
-                    ),
-                    parser.get_shutter_direction(
-                        get_shutter_discovery_packet_index(device_type, 0)
-                    ),
+                    [
+                        parser.get_shutter_position(
+                            get_shutter_discovery_packet_index(device_type, 0)
+                        )
+                    ],
+                    [
+                        parser.get_shutter_direction(
+                            get_shutter_discovery_packet_index(device_type, 0)
+                        )
+                    ],
+                    [
+                        parser.get_shutter_child_lock(
+                            get_shutter_discovery_packet_index(device_type, 0)
+                        )
+                    ],
                     [
                         parser.get_light_state(
                             get_light_discovery_packet_index(device_type, 0)
@@ -188,6 +209,53 @@ def _parse_device_from_datagram(
                 )
             )
 
+        elif (
+            device_type
+            and device_type.category == DeviceCategory.DUAL_SHUTTER_SINGLE_LIGHT
+        ):
+            logger.debug("discovered a Runner S12 switcher device")
+            device_callback(
+                SwitcherDualShutterSingleLight(
+                    device_type,
+                    DeviceState.ON,
+                    parser.get_device_id(),
+                    parser.get_device_key(),
+                    parser.get_ip_type2(),
+                    parser.get_mac_type2(),
+                    parser.get_name(),
+                    device_type.token_needed,
+                    [
+                        parser.get_shutter_position(
+                            get_shutter_discovery_packet_index(device_type, 0)
+                        ),
+                        parser.get_shutter_position(
+                            get_shutter_discovery_packet_index(device_type, 1)
+                        ),
+                    ],
+                    [
+                        parser.get_shutter_direction(
+                            get_shutter_discovery_packet_index(device_type, 0)
+                        ),
+                        parser.get_shutter_direction(
+                            get_shutter_discovery_packet_index(device_type, 1)
+                        ),
+                    ],
+                    [
+                        parser.get_shutter_child_lock(
+                            get_shutter_discovery_packet_index(device_type, 0)
+                        ),
+                        parser.get_shutter_child_lock(
+                            get_shutter_discovery_packet_index(device_type, 1)
+                        ),
+                    ],
+                    [
+                        parser.get_light_state(
+                            get_light_discovery_packet_index(device_type, 0)
+                        )
+                    ],
+                )
+            )
+
         elif device_type and device_type.category == DeviceCategory.THERMOSTAT:
             logger.debug("discovered a Breeze switcher device")
             device_callback(
@@ -208,6 +276,87 @@ def _parse_device_from_datagram(
                     parser.get_thermostat_remote_id(),
                 )
             )
+
+        elif (
+            device_type
+            and device_type.category == DeviceCategory.LIGHT
+            and device_type in (DeviceType.LIGHT_SL01, DeviceType.LIGHT_SL01_MINI)
+        ):
+            logger.debug("discovered a Light SL01 switcher device")
+            device_callback(
+                SwitcherLight(
+                    device_type,
+                    DeviceState.ON,
+                    parser.get_device_id(),
+                    parser.get_device_key(),
+                    parser.get_ip_type2(),
+                    parser.get_mac_type2(),
+                    parser.get_name(),
+                    device_type.token_needed,
+                    [
+                        parser.get_light_state(
+                            get_light_discovery_packet_index(device_type, 0)
+                        )
+                    ],
+                )
+            )
+
+        elif (
+            device_type
+            and device_type.category == DeviceCategory.LIGHT
+            and device_type in (DeviceType.LIGHT_SL02, DeviceType.LIGHT_SL02_MINI)
+        ):
+            logger.debug("discovered a Light SL02 switcher device")
+            device_callback(
+                SwitcherLight(
+                    device_type,
+                    DeviceState.ON,
+                    parser.get_device_id(),
+                    parser.get_device_key(),
+                    parser.get_ip_type2(),
+                    parser.get_mac_type2(),
+                    parser.get_name(),
+                    device_type.token_needed,
+                    [
+                        parser.get_light_state(
+                            get_light_discovery_packet_index(device_type, 0)
+                        ),
+                        parser.get_light_state(
+                            get_light_discovery_packet_index(device_type, 1)
+                        ),
+                    ],
+                )
+            )
+
+        elif (
+            device_type
+            and device_type.category == DeviceCategory.LIGHT
+            and device_type == DeviceType.LIGHT_SL03
+        ):
+            logger.debug("discovered a Light SL03 switcher device")
+            device_callback(
+                SwitcherLight(
+                    device_type,
+                    DeviceState.ON,
+                    parser.get_device_id(),
+                    parser.get_device_key(),
+                    parser.get_ip_type2(),
+                    parser.get_mac_type2(),
+                    parser.get_name(),
+                    device_type.token_needed,
+                    [
+                        parser.get_light_state(
+                            get_light_discovery_packet_index(device_type, 0)
+                        ),
+                        parser.get_light_state(
+                            get_light_discovery_packet_index(device_type, 1)
+                        ),
+                        parser.get_light_state(
+                            get_light_discovery_packet_index(device_type, 2)
+                        ),
+                    ],
+                )
+            )
         else:
             warn("discovered an unknown switcher device")
 
@@ -218,26 +367,12 @@ class SwitcherBridge:
 
     Args:
         on_device: a callable to which every new SwitcherBase device found will be send.
-        broadcast_ports: broadcast ports list, default for type 1 devices is 20002,
-            default for type 2 devices is 20003.
-            On newer type1 devices, the port is 10002.
-            On newer type2 devices, the port is 10003.
 
     """
 
-    def __init__(
-        self,
-        on_device: Callable[[SwitcherBase], Any],
-        broadcast_ports: List[int] = [
-            SWITCHER_UDP_PORT_TYPE1,
-            SWITCHER_UDP_PORT_TYPE1_NEW_VERSION,
-            SWITCHER_UDP_PORT_TYPE2,
-            SWITCHER_UDP_PORT_TYPE2_NEW_VERSION,
-        ],
-    ) -> None:
+    def __init__(self, on_device: Callable[[SwitcherBase], Any]) -> None:
         """Initialize the switcher bridge."""
         self._on_device = on_device
-        self._broadcast_ports = broadcast_ports
         self._is_running = False
         self._transports: Dict[int, Optional[BaseTransport]] = {}
 
@@ -257,7 +392,7 @@ class SwitcherBridge:
 
     async def start(self) -> None:
         """Create an asynchronous listener and start the bridge."""
-        for broadcast_port in self._broadcast_ports:
+        for broadcast_port in SWITCHER_UDP_BROADCAST_PORTS:
             logger.info("starting the udp bridge on port %s", broadcast_port)
             protocol_factory = UdpClientProtocol(
                 partial(_parse_device_from_datagram, self._on_device)
@@ -274,7 +409,7 @@ class SwitcherBridge:
 
     async def stop(self) -> None:
         """Stop the asynchronous bridge."""
-        for broadcast_port in self._broadcast_ports:
+        for broadcast_port in SWITCHER_UDP_BROADCAST_PORTS:
             transport = self._transports.get(broadcast_port)
 
             if transport and not transport.is_closing():
@@ -336,7 +471,10 @@ class DatagramParser:
             len(self.message) == 165
             or len(self.message) == 168  # Switcher Breeze
             or len(self.message) == 159  # Switcher Runner and RunnerMini
-            or len(self.message) == 203  # Switcher Runner S11
+            or len(self.message) == 203  # Switcher Runner S11 and Switcher Runner S12
+            or len(self.message)
+            == 207  # Switcher Light SL01, Switcher Light SL01 Mini,
+            # Switcher Light SL02, Switcher Light SL02 Mini and Switcher Light SL03
         )
 
     def get_ip_type1(self) -> str:
@@ -458,6 +596,18 @@ class DatagramParser:
         directions = dict(map(lambda d: (d.value, d), ShutterDirection))
         return directions[hex_direction]
 
+    def get_shutter_child_lock(self, index: int) -> ShutterChildLock:
+        """Extract the shutter child lock state from the broadcast message."""
+        start_index = 136 + (index * 16)
+        end_index = start_index + 2
+        hex_pos = hexlify(self.message[start_index:end_index]).decode()
+        hex_device_state = hex_pos[0:2]
+        return (
+            ShutterChildLock.ON
+            if hex_device_state == ShutterChildLock.ON.value
+            else ShutterChildLock.OFF
+        )
+
     def get_light_state(self, index: int) -> DeviceState:
         """Extract the light state from the broadcast message."""
         start_index = 135 + (index * 16)
