@@ -25,7 +25,12 @@ import pytest_asyncio
 from assertpy import assert_that
 from pytest import fixture, mark, raises
 
-from aioswitcher.api import Command, SwitcherType1Api, SwitcherType2Api
+from aioswitcher.api import (
+    SWITCHER_TCP_PORT_TYPE1,
+    SWITCHER_TCP_PORT_TYPE2,
+    Command,
+    SwitcherApi,
+)
 from aioswitcher.api.messages import (
     SwitcherBaseResponse,
     SwitcherGetSchedulesResponse,
@@ -43,6 +48,7 @@ from aioswitcher.api.remotes import (
 from aioswitcher.device import (
     DeviceState,
     DeviceType,
+    ShutterChildLock,
     ThermostatFanLevel,
     ThermostatMode,
     ThermostatSwing,
@@ -56,6 +62,8 @@ device_index2 = 1
 device_id = "aaaaaa"
 device_key = "18"
 device_ip = "1.2.3.4"
+device_port = SWITCHER_TCP_PORT_TYPE1
+device_port2 = SWITCHER_TCP_PORT_TYPE2
 token_empty = ""
 token_not_empty = "zvVvd7JxtN7CgvkD1Psujw=="
 pytestmark = mark.asyncio
@@ -85,7 +93,7 @@ def writer_mock(writer_write):
 @pytest_asyncio.fixture
 async def connected_api_type1(reader_mock, writer_mock):
     with patch("aioswitcher.api.open_connection", return_value=(reader_mock, writer_mock)):
-        api = SwitcherType1Api(device_type_api1, device_ip, device_id, device_key)
+        api = SwitcherApi(device_type_api1, device_ip, device_id, device_key)
         await api.connect()
         yield api
         await api.disconnect()
@@ -94,7 +102,7 @@ async def connected_api_type1(reader_mock, writer_mock):
 @pytest_asyncio.fixture
 async def connected_api_type2(reader_mock, writer_mock):
     with patch("aioswitcher.api.open_connection", return_value=(reader_mock, writer_mock)):
-        api = SwitcherType2Api(device_type_api2, device_ip, device_id, device_key, token_empty)
+        api = SwitcherApi(device_type_api2, device_ip, device_id, device_key, token_empty)
         await api.connect()
         yield api
         await api.disconnect()
@@ -103,7 +111,7 @@ async def connected_api_type2(reader_mock, writer_mock):
 @pytest_asyncio.fixture
 async def connected_api_token_type2(reader_mock, writer_mock):
     with patch("aioswitcher.api.open_connection", return_value=(reader_mock, writer_mock)):
-        api = SwitcherType2Api(device_type_token_api2, device_ip, device_id, device_key, token_not_empty)
+        api = SwitcherApi(device_type_token_api2, device_ip, device_id, device_key, token_not_empty)
         await api.connect()
         yield api
         await api.disconnect()
@@ -111,7 +119,7 @@ async def connected_api_token_type2(reader_mock, writer_mock):
 
 @patch("logging.Logger.info")
 async def test_stopping_before_started_and_connected_should_write_to_the_info_output(mock_info):
-    api = SwitcherType1Api(device_type_api1, device_ip, device_id, device_key)
+    api = SwitcherApi(device_type_api1, device_ip, device_id, device_key)
     assert_that(api.connected).is_false()
     await api.disconnect()
     mock_info.assert_called_with("switcher device not connected")
@@ -119,14 +127,14 @@ async def test_stopping_before_started_and_connected_should_write_to_the_info_ou
 
 async def test_api_as_a_context_manager(reader_mock, writer_mock):
     with patch("aioswitcher.api.open_connection", return_value=(reader_mock, writer_mock)):
-        async with SwitcherType1Api(device_type_api1, device_ip, device_id, device_key) as api:
+        async with SwitcherApi(device_type_api1, device_ip, device_id, device_key) as api:
             assert_that(api.connected).is_true()
 
 
 async def test_api_with_token_needed_but_missing_should_raise_error():
     with raises(RuntimeError, match="A token is needed but is missing"):
         with patch("aioswitcher.api.open_connection", return_value=b''):
-            await SwitcherType2Api(device_type_token_api2, device_ip, device_id, device_key, token_empty)
+            await SwitcherApi(device_type_token_api2, device_ip, device_id, device_key, token_empty)
 
 
 async def test_login_function(reader_mock, writer_write, connected_api_type1, resource_path_root):
@@ -448,6 +456,24 @@ async def test_set_shutter_position_token_device_function_with_valid_packets(rea
     assert_that(response.unparsed_response).is_equal_to(three_packets[-1])
 
 
+async def test_set_shutter_child_lock_function_with_valid_packets(reader_mock, writer_write, connected_api_type2, resource_path_root):
+    two_packets = _get_dummy_packets(resource_path_root, "login_response", "set_set_shutter_child_response")
+    with patch.object(reader_mock, "read", side_effect=two_packets):
+        response = await connected_api_type2.set_shutter_child_lock(ShutterChildLock.ON, device_index)
+    assert_that(writer_write.call_count).is_equal_to(2)
+    assert_that(response).is_instance_of(SwitcherBaseResponse)
+    assert_that(response.unparsed_response).is_equal_to(two_packets[-1])
+
+
+async def test_set_shutter_child_lock_token_device_function_with_valid_packets(reader_mock, writer_write, connected_api_token_type2, resource_path_root):
+    three_packets = _get_dummy_packets(resource_path_root, "login_response", "login2_response", "set_set_shutter_child_response")
+    with patch.object(reader_mock, "read", side_effect=three_packets):
+        response = await connected_api_token_type2.set_shutter_child_lock(ShutterChildLock.ON, device_index)
+    assert_that(writer_write.call_count).is_equal_to(3)
+    assert_that(response).is_instance_of(SwitcherBaseResponse)
+    assert_that(response.unparsed_response).is_equal_to(three_packets[-1])
+
+
 async def test_get_light_state_function_with_valid_packets(reader_mock, writer_write, connected_api_token_type2, resource_path_root):
     three_packets = _get_dummy_packets(resource_path_root, "login_response", "login2_response", "get_light_state_response")
     with patch.object(reader_mock, "read", side_effect=three_packets):
